@@ -307,8 +307,14 @@ watch_for_change (GCupsConnectionSelector *cs, char const *name)
 static GCupsConnectionType
 get_connection_type (GladeXML *xml)
 {
-	GtkComboBox *combo = (GtkComboBox *)glade_xml_get_widget (xml, "connection_types");
-	int tmp = gtk_combo_box_get_active (combo);
+	GtkWidget *w = glade_xml_get_widget (xml, "local_connect_radio");
+	int tmp;
+
+	if (gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (w)))
+		return GCUPS_CONNECTION_LOCAL;
+
+	w = glade_xml_get_widget (xml, "connection_types");
+	tmp = gtk_combo_box_get_active (GTK_COMBO_BOX (w));
 	if (tmp >= 0)
 		return (GCupsConnectionType)tmp;
 	return GCUPS_CONNECTION_IPP;
@@ -756,20 +762,25 @@ cb_smb_host_changed (GtkComboBox *combo, GladeXML *xml)
 /*****************************************************************************/
 
 static void
-cb_connection_type_changed (GtkComboBox *combo, GCupsConnectionSelector *cs)
+cb_connection_type_changed (GCupsConnectionSelector *cs)
 {
 	static gboolean start_smb_scan = TRUE;
+	GtkWidget *w = glade_xml_get_widget (cs->xml, "local_connect_radio");
 	GtkWidget *notebook = glade_xml_get_widget (cs->xml, "connection_notebook");
-	gtk_notebook_set_current_page (GTK_NOTEBOOK (notebook),
-		gtk_combo_box_get_active (combo));
+	GtkWidget *combo = glade_xml_get_widget (cs->xml, "connection_types");
+	int t = gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (w))
+		? GCUPS_CONNECTION_LOCAL
+		: gtk_combo_box_get_active (GTK_COMBO_BOX (combo));
+	gtk_notebook_set_current_page (GTK_NOTEBOOK (notebook), t);
+	gtk_widget_set_sensitive (combo, t != GCUPS_CONNECTION_LOCAL);
 
 	if (cs->updating)
 		return;
 
-#ifdef HAVE_LIBSMBCLIENT
 	if (start_smb_scan &&
 	    get_connection_type (cs->xml) == GCUPS_CONNECTION_SMB) {
 		start_smb_scan = FALSE;
+#ifdef HAVE_LIBSMBCLIENT
 		if (smbc_init (smb_auth_fn, 0) >= 0) {
 			if (!g_thread_supported ())
 				g_thread_init (NULL);
@@ -779,8 +790,10 @@ cb_connection_type_changed (GtkComboBox *combo, GCupsConnectionSelector *cs)
 			g_warning ("smbc_init returned %s (%i)\nDo you have a ~/.smb/smb.conf file?\n",
 				   strerror (errno), errno);
 		}
-	}
+#else
+		g_warning ("no smb browsing support");
 #endif
+	}
 }
 
 static void
@@ -893,6 +906,7 @@ setup_network_connections (GCupsConnectionSelector *cs)
 
 	init_smb_combos (cs->xml);
 
+	watch_for_change (cs, "local_connect_radio");
 	watch_for_change (cs, "connection_types");
 	watch_for_change (cs, "lpd_host_entry");
 	watch_for_change (cs, "smb_username_entry");
@@ -902,9 +916,15 @@ setup_network_connections (GCupsConnectionSelector *cs)
 	watch_for_change (cs, "ipp_uri_entry");
 	watch_for_change (cs, "hp_host_entry");
 	watch_for_change (cs, "hp_port_entry");
-	g_signal_connect (glade_xml_get_widget (cs->xml, "connection_types"),
+	cs->updating = TRUE;
+	cb_connection_type_changed (cs);
+	cs->updating = FALSE;
+	g_signal_connect_swapped (glade_xml_get_widget (cs->xml, "connection_types"),
 		"changed",
 		G_CALLBACK (cb_connection_type_changed), cs);
+	g_signal_connect_swapped (glade_xml_get_widget (cs->xml, "local_connect_radio"),
+		"toggled",
+		G_CALLBACK (cb_connection_type_changed), cs);
 
 	w = glade_xml_get_widget (cs->xml, "ipp_uri_entry");
 	gtk_tooltips_set_tip (gtk_tooltips_new (), w,
@@ -960,6 +980,8 @@ parse_network_detect (char const *line)
 	char **p;
 	char *sep;
 
+	g_warning ("snmp result == '%s'", line);
+
 	sep = strchr (line, '\n');
 	if (sep) {
 		*sep = '\0';
@@ -1018,7 +1040,7 @@ gcups_connection_selector_init (GCupsConnectionSelector *cs)
 
 	w = glade_xml_get_widget (cs->xml, "gcups_connection_selector");
 	gtk_container_add (GTK_CONTAINER (cs), w);
-	gtk_widget_show_all (GTK_WIDGET (cs));
+	gtk_widget_show (GTK_WIDGET (cs));
 }
 
 GtkWidget *
@@ -1131,6 +1153,8 @@ gcups_connection_selector_set_uri (GCupsConnectionSelector *cs, char const *uri)
 
 	cs->updating = TRUE;
 
+	g_warning ("connect = '%s'", uri);
+
 	/* Check for local devices first */
 	ptr = g_object_get_data (G_OBJECT (cs->xml), "local-devices");
 	for (; ptr != NULL ; ptr = ptr->next) {
@@ -1141,13 +1165,12 @@ gcups_connection_selector_set_uri (GCupsConnectionSelector *cs, char const *uri)
 
 	if (ptr == NULL) {
 		httpSeparate (uri, method, username, host, &port, res_buf);
-#if 0
-		g_warning ("uri\t == '%s'\n"
-			   "method\t:'%s'\n"
+#if 1
+		g_warning ("method\t:'%s'\n"
 			   "user\t:'%s'\n"
 			   "host\t:'%s'\n"
 			   "port\t:%d\n"
-			   "resource\t:'%s'\n", uri, method, username, host, port, res_buf);
+			   "resource\t:'%s'\n", method, username, host, port, res_buf);
 
 		resource = res_buf + ((res_buf[0] == '/') ? 1 : 0);
 #endif
@@ -1213,7 +1236,14 @@ gcups_connection_selector_set_uri (GCupsConnectionSelector *cs, char const *uri)
 		type = GCUPS_CONNECTION_IPP;
 	}
 
-	w  = glade_xml_get_widget (cs->xml, "connection_types");
-	gtk_combo_box_set_active (GTK_COMBO_BOX (w), type);
+	if (type == GCUPS_CONNECTION_LOCAL) {
+		w  = glade_xml_get_widget (cs->xml, "local_connect_radio");
+		gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (w), TRUE);
+	} else {
+		w  = glade_xml_get_widget (cs->xml, "network_connect_radio");
+		gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (w), TRUE);
+		w  = glade_xml_get_widget (cs->xml, "connection_types");
+		gtk_combo_box_set_active (GTK_COMBO_BOX (w), type);
+	}
 	cs->updating = FALSE;
 }
